menu
dart_code_metrics_annotations package
documentation
annotations.dart
annotations.dart
dark_mode
light_mode
annotations
library
Classes
AcceptedTypes
Used to annotate fields or parameters that have a type
Object
, but should only receive a known subset of types (e.g.
String
and
int
).
Throws
Used to annotate getters, methods, functions, parameters or local variables that can throw an exception (or multiple exceptions/errors) and therefore an invocation of such declarations must explicitly handle that exception.
Constants
mutated
→ const _IsMutated
Used to annotate parameters or variables that are changed/updated within the function/method body.
dart_code_metrics_annotations package
documentation
annotations.dart
dart_code_metrics_annotations
package
Libraries
annotations
annotations library